@@ -2,20 +2,20 @@
 #this repository contains the full copyright notices and license terms.
 from trytond.pool import Pool
 from .move import *
-from .configuration import *
 from .party import *
 from .invoice import *
 from .account import *
+from .tax import *
 
 def register():
     Pool.register(
+        Tax,
         Company,
         Address,
         CashflowTemplate,
         Cashflow,
         Account,
         Party,
-        Configuration,
         Move,
         Line,
         Invoice,
@@ -27,6 +27,7 @@ def register():
         BankAccountNumber,
         OpenCashflowStart,
         MoveFixNumberStart,
+        PartyWithholdingStart,
         module='account_plus', type_='model')
     Pool.register(
         AccountMoveSheet,
@@ -38,6 +39,7 @@ def register():
         BalanceSheet,
         IncomeStatement,
         EquivalentInvoice,
+        PartyWithholding,
         module='account_plus', type_='report')
     Pool.register(
         MoveForceDraw,
@@ -48,4 +50,5 @@ def register():
         PrintTrialBalance,
         OpenCashflowStatement,
         MoveFixNumber,
+        PrintPartyWithholding,
         module='account_plus', type_='wizard')
