@@ -62,8 +62,18 @@ class AuxiliaryBookStart(ModelView):
             ('start_date', '>=', (Eval('start_period'), 'start_date'))
             ],
         depends=['fiscalyear', 'start_period'])
-    start_code = fields.Char('Start Code Range')
-    end_code = fields.Char('End Code Range')
+    start_account = fields.Many2One('account.account', 'Start Account',
+            domain=[ 
+                ('kind', '!=', 'view'),
+                ('code', '!=', None),
+            ])
+    end_account = fields.Many2One('account.account', 'End Account',
+            domain=[ 
+                ('kind', '!=', 'view'),
+                ('code', '!=', None),
+            ])
+    #start_code = fields.Char('Start Code Range')
+    #end_code = fields.Char('End Code Range')
     party = fields.Many2One('party.party', 'Party')
     company = fields.Many2One('company.company', 'Company', required=True)
     posted = fields.Boolean('Posted Move', help='Show only posted move')
@@ -120,14 +130,23 @@ class PrintAuxiliaryBook(Wizard):
             party = None
         else:
             party = self.start.party.id
+
+        start_account_id = None
+        if self.start.start_account:
+            start_account_id = self.start.start_account.id
+        end_account_id = None
+        if self.start.end_account:
+            end_account_id = self.start.end_account.id
+
+
         data = {
             'company': self.start.company.id,
             'fiscalyear': self.start.fiscalyear.id,
             'start_period': start_period,
             'end_period': end_period,
             'posted': self.start.posted,
-            'start_code': self.start.start_code,
-            'end_code': self.start.end_code,
+            'start_account': start_account_id,
+            'end_account': end_account_id,
             'party': party,
             'empty_account': self.start.empty_account,
             }
@@ -149,24 +168,29 @@ class AuxiliaryBook(Report):
         Party = pool.get('party.party')
         company = Company(data['company'])
 
-        accounts = Account.search([
-                ('company', '=', data['company']),
-                ('kind', '!=', 'view'),
-                ], order=[('code', 'ASC'), ('id', 'ASC')])
-
         start_period_name = None
         end_period_name = None
 
-        if data['start_code'] or data['end_code']:
-            if not data['start_code']:
-                start_code = 0
-            else:
-                start_code = fmt_acc(data['start_code'])
-            if not data['end_code']:
-                end_code = 99999999
-            else:
-                end_code = fmt_acc(data['end_code'])
-            accounts = cls.get_accounts_range(accounts, start_code, end_code)
+        dom_accounts = [
+                ('company', '=', data['company']),
+                ('kind', '!=', 'view'),
+                ]
+        start_code = None
+        if data['start_account']:
+            start_acc = Account(data['start_account'])
+            start_code = start_acc.code
+            dom_accounts.append(
+                ('code', '>=', start_acc.code)
+            )
+        end_code = None
+        if data['end_account']:
+            end_acc = Account(data['end_account'])
+            end_code = end_acc.code
+            dom_accounts.append(
+                ('code', '<=', end_acc.code)
+            )
+
+        accounts = Account.search(dom_accounts, order=[('code', 'ASC')])
 
         party = None
         if data['party']:
@@ -241,8 +265,8 @@ class AuxiliaryBook(Report):
         # --------------------------------------------------------------
         localcontext['start_period_name'] = start_period_name
         localcontext['end_period_name'] = end_period_name
-        localcontext['start_code'] = data['start_code']
-        localcontext['end_code'] = data['end_code']
+        localcontext['start_code'] = start_code
+        localcontext['end_code'] = end_code
         localcontext['party'] = party
         localcontext['accounts'] = accounts
         localcontext['id2start_account'] = id2start_account
@@ -253,15 +277,6 @@ class AuxiliaryBook(Report):
         return super(AuxiliaryBook, cls).parse(report, objects, data,
             localcontext)
 
-    @classmethod
-    def get_accounts_range(cls, accounts, start_code, end_code):
-        filtered_accounts = []
-        for account in accounts:
-            val = fmt_acc(account.code)
-            if val >= start_code and val <= end_code:
-                filtered_accounts.append(account)
-        return filtered_accounts
-
     @classmethod
     def get_lines(cls, accounts, periods, posted, party=None):
         MoveLine = Pool().get('account.move.line')
@@ -374,8 +389,6 @@ class PrintTrialBalanceDetailedStart(ModelView):
             ('start_date', '>=', (Eval('start_period'), 'start_date'))
             ],
         depends=['start_period', 'fiscalyear'])
-    start_code = fields.Integer('Start Code')
-    end_code = fields.Integer('End Code')
     party = fields.Many2One('party.party', 'Party')
     company = fields.Many2One('company.company', 'Company', required=True)
     posted = fields.Boolean('Posted Move', help='Show only posted move')
@@ -431,21 +444,11 @@ class PrintTrialBalanceDetailed(Wizard):
             party_id = self.start.party.id
         else:
             party_id = None
-        if self.start.start_code:
-            start_code = self.start.start_code
-        else:
-            start_code = None
-        if self.start.end_code:
-            end_code = self.start.end_code
-        else:
-            end_code = None
         data = {
             'company': self.start.company.id,
             'fiscalyear': self.start.fiscalyear.id,
             'start_period': start_period,
             'end_period': end_period,
-            'start_code': start_code,
-            'end_code': end_code,
             'party': party_id,
             'posted': self.start.posted,
             'empty_account': self.start.empty_account,
@@ -559,7 +562,7 @@ class TrialBalanceDetailed(Report):
                 if code not in start_accounts.keys():
                     start_accounts[code] = {}
                 start_accounts[code].update({r[1]: r[2]})
-        # agregar rango de cuentas
+
         accounts = {}
         for r in res:
             vat_number = ''
