@@ -5,7 +5,7 @@ from trytond.pool import PoolMeta, Pool
 from trytond.model import fields
 from trytond.pyson import Eval
 
-__all__ = ['Party', 'BankAccountNumber', 'Address']
+__all__ = ['Party', 'BankAccountNumber', 'Address', 'Company']
 __metaclass__ = PoolMeta
 
 PRIMOS = [71,67,59,53,47,43,41,37,29,23,19,17,13,7,3]
@@ -122,3 +122,8 @@ class Address:
         ])
         if countries:
             return countries[0].id
+
+
+class Company:
+    __name__ = 'company.company'
+    resolution_gta = fields.Char('Resolution GTA')
